@@ -178,8 +178,9 @@ def main():
             if args.tirp:
                 console.log(testme.get_tirps())
         elif args.command == "query":
-            if util.is_valid_date(args.start_time) or (
-                not args.end_time and util.is_valid_date(args.start_time)
+            if not (
+                util.is_valid_date(args.start_time)
+                or (not args.end_time and util.is_valid_date(args.end_time))
             ):
                 console.log(
                     "[bold red]Error: Please use the correct time format ![/bold red]"
