@@ -47,7 +47,7 @@ class litUesr:
         # login func
         try:
             response = requests.post(
-                url=endpoints["login"], data=json.dumps(data), headers=self.__headers
+                url=endpoints["login"], data=json.dumps(data), headers=self.__headers, timeout=5
             )
         except:
             return None
@@ -61,7 +61,7 @@ class litUesr:
 
         try:
             response = requests.get(
-                url=endpoints["lastRecord"], params=data, headers=self.__headers
+                url=endpoints["lastRecord"], params=data, headers=self.__headers, timeout=5
             )
         except:
             return None
@@ -105,7 +105,7 @@ class litUesr:
 
         try:
             response = requests.get(
-                url=endpoints["getInstructor"], params=data, headers=self.__headers
+                url=endpoints["getInstructor"], params=data, headers=self.__headers, timeout=5
             )
         except:
             return None
@@ -121,7 +121,7 @@ class litUesr:
 
         try:
             response = requests.get(
-                url=endpoints["getFamilys"], params=data, headers=self.__headers
+                url=endpoints["getFamilys"], params=data, headers=self.__headers, timeout=5
             )
         except:
             return None
@@ -133,7 +133,7 @@ class litUesr:
     def get_important_city(self):
         try:
             response = requests.get(
-                url=endpoints["getImportantCity"], headers=self.__headers
+                url=endpoints["getImportantCity"], headers=self.__headers, timeout=5
             )
         except:
             return None
@@ -149,7 +149,7 @@ class litUesr:
 
         try:
             response = requests.get(
-                url=endpoints["getTrips"], params=data, headers=self.__headers
+                url=endpoints["getTrips"], params=data, headers=self.__headers, timeout=5
             )
         except:
             return None
@@ -157,7 +157,7 @@ class litUesr:
         res = response.json()
 
         return res
-
+    
     def query_record(self, st=util.get_today_time, et=util.get_today_time):
         data = {
             "pageNum": 1,
@@ -170,7 +170,7 @@ class litUesr:
 
         try:
             response = requests.get(
-                url=endpoints["queryRecord"], params=data, headers=self.__headers
+                url=endpoints["queryRecord"], params=data, headers=self.__headers, timeout=5
             )
         except:
             return None
@@ -272,9 +272,7 @@ class litUesr:
             "currentProvince": last_record["currentProvince"],
             "currentCity": last_record["currentCity"],
             "currentDistrict": last_record["currentDistrict"],
-            "currentLocation": util.current_location(
-                last_record["currentDistrict"], last_record["currentCity"]
-            ),
+            "currentLocation": "",
             "currentAddress": last_record["currentAddress"],
             "villageIsCase": last_record["villageIsCase"],
             "caseAddress": last_record["caseAddress"],
@@ -300,9 +298,7 @@ class litUesr:
             "contactProvince": last_record["contactProvince"],
             "contactCity": last_record["contactCity"],
             "contactDistrict": last_record["contactDistrict"],
-            "contactLocation": util.current_location(
-                last_record["contactDistrict"], last_record["contactCity"]
-            ),
+            "contactLocation": "",
             "contactAddress": last_record["contactAddress"],
             "isAbroad": last_record["isAbroad"],
             "abroadInfo": last_record["abroadInfo"],
@@ -325,25 +321,31 @@ class litUesr:
             if rtimes == 3:
                 data["temperatureThree"] = last_record["temperatureThree"]
         elif mode == "random":
-            data["temperature"] = util.random_temp()
+            data["temperature"] = str(util.random_temp())
             if rtimes >= 2:
-                data["temperatureTwo"] = util.random_temp()
+                data["temperatureTwo"] = str(util.random_temp())
             if rtimes == 3:
-                data["temperatureThree"] = util.random_temp()
+                data["temperatureThree"] = str(util.random_temp())
         elif mode == "manual":
-            data["temperature"] = temperature
+            data["temperature"] = str(temperature)
             if rtimes >= 2:
-                data["temperatureTwo"] = temperatureTwo
+                data["temperatureTwo"] = str(temperatureTwo)
             if rtimes == 3:
-                data["temperatureThree"] = temperatureThree
+                data["temperatureThree"] = str(temperatureThree)
         else:
             return None
 
+        # check temperature
+        if rtimes >= 2 and data["temperatureTwo"] == "":
+            print("Warning: Incorrect temperatureTwo!")
+        if rtimes == 3 and data["temperatureThree"] == "":
+            print("Warning: Incorrect temperatureThree!")
+
         try:
             response = requests.post(
                 url=endpoints["firstRecord"],
                 data=json.dumps(data),
-                headers=self.__headers,
+                headers=self.__headers, timeout=5,
             )
         except:
             return None
@@ -375,15 +377,19 @@ class litUesr:
         if mode == "last":
             pass
         elif mode == "random":
-            data["temperature"] = util.random_temp()
+            data["temperature"] = str(util.random_temp())
         elif mode == "manual":
-            data["temperature"] = temperature
+            data["temperature"] = str(temperature)
         else:
             return None
 
+        # check temperature
+        if data["temperature"] == "":
+            print("Warning: Incorrect temperatureTwo!")
+
         try:
             response = requests.put(
-                url=endpoints["secondRecord"], params=data, headers=self.__headers
+                url=endpoints["secondRecord"], params=data, headers=self.__headers, timeout=5
             )
         except:
             return None
@@ -410,15 +416,19 @@ class litUesr:
         if mode == "last":
             pass
         elif mode == "random":
-            data["temperature"] = util.random_temp()
+            data["temperature"] = str(util.random_temp())
         elif mode == "manual":
-            data["temperature"] = temperature
+            data["temperature"] = str(temperature)
         else:
             return None
 
+        # check temperature
+        if data["temperature"] == "":
+            print("Warning: Incorrect temperatureThree!")
+
         try:
             response = requests.put(
-                url=endpoints["thirdRecord"], params=data, headers=self.__headers
+                url=endpoints["thirdRecord"], params=data, headers=self.__headers, timeout=5
             )
         except:
             return None
@@ -436,7 +446,7 @@ class litUesr:
 
         try:
             response = requests.put(
-                url=endpoints["password"], params=data, headers=self.__headers
+                url=endpoints["password"], params=data, headers=self.__headers, timeout=5
             )
         except:
             return None
